@@ -17,6 +17,16 @@ sub execute {
     my $self = shift;
     my ( $controller, $c, $serializer ) = @_;
 
+    my $sp = $serializer;
+    $sp =~ s/::/\//g;
+    $sp .= ".pm";
+    eval {
+        require $sp
+    };
+    if ($@) {
+        $c->log->debug("Could not load $serializer, refusing to serialize: $@");
+        return 0;
+    }
     my $body = $c->request->body;
     if ($body) {
         my $rbody;
@@ -28,12 +38,19 @@ sub execute {
             close(BODY);
         }
         my $dso = Data::Serializer->new( serializer => $serializer );
-        my $rdata = $dso->raw_deserialize($rbody);
+        my $rdata;
+        eval {
+            $rdata = $dso->raw_deserialize($rbody);
+        };
+        if ($@) {
+            return $@;
+        }
         $c->request->data($rdata);
     } else {
         $c->log->debug(
             'I would have deserialized, but there was nothing in the body!');
     }
+    return 1;
 }
 
 1;
