@@ -19,12 +19,19 @@ sub execute {
 
     my $body = $c->request->body;
     if ($body) {
-        my $rdata = LoadFile( $c->request->body );
+        my $rdata;
+        eval {
+            $rdata = LoadFile( $c->request->body );
+        };
+        if ($@) {
+            return $@;
+        }
         $c->request->data($rdata);
     } else {
         $c->log->debug(
             'I would have deserialized, but there was nothing in the body!');
     }
+    return 1;
 }
 
 1;
